@@ -61,6 +61,12 @@ file_check()
         exit 1 
      fi
 
+     if [ ! -f snare.xml ]
+     then
+        echo "The Snare SMF script is missing. Terminating script."
+        exit 1 
+     fi
+
      if [ ! -f uninstall.sh ]
      then
         echo "The snare removal script is missing. Terminating script."
@@ -152,6 +158,21 @@ check_os_and_patch_level()
    if [ $RETVAL -lt 1 ]; then
 	echo "No additional patches are required for Solaris 9. Continuing."
    fi
+
+   uname -r | grep 5.10 > /dev/null
+   RETVAL=$?
+
+   if [ $RETVAL -lt 1 ]
+   then
+	svcs svc:/system/auditd:default > /dev/null 2>&1 
+	RETVAL=$?
+
+        if [ $RETVAL -lt 1 ]
+	then
+		echo "Configuring Snare for SMF."
+	fi
+	echo "No additional patches are required for Solaris 10. Continuing."
+   fi
 }
 
 ########################################################################
@@ -200,8 +221,14 @@ backup_key_files()
       RETVAL=$?
       if [ $RETVAL -gt 0 ]
       then
-        echo "Unable to backup the /etc/init.d/audit file to /etc/security. Terminating script"
-        exit 1
+	   uname -r | grep 5.10 > /dev/null
+	   RETVAL=$?
+
+	   if [ $RETVAL -gt 0 ]
+	   then
+		echo "Unable to backup the /etc/init.d/audit file to /etc/security. Terminating script"
+		exit 1
+	   fi
       fi
    else
       echo "Backup of audit already exists. Not overwriting"
@@ -249,6 +276,8 @@ backup_key_files()
 check_audit_is_on
 file_check 
 root_check
+svcs svc:/system/auditd:default > /dev/null 2>&1 
+SMFAUDITD=$?
 check_os_and_patch_level
 backup_key_files
 
@@ -259,13 +288,13 @@ if [ -f /etc/security/snare.conf ]; then
    SNAREC=1
 fi
 
-if [ -f /etc/init.d/snare ]; then
-	echo "WARNING: It looks as though Snare is already installed."
-	echo
-	echo "Please uninstall Snare first before proceeding: ./uninstall.sh"
-	echo
-	exit
-fi
+	if [ -f /etc/init.d/snare ] || [ -f /var/svc/manifest/application/security/snare.xml ]; then
+		echo "WARNING: It looks as though Snare is already installed."
+		echo
+		echo "Please uninstall Snare first before proceeding: ./uninstall.sh"
+		echo
+		exit
+	fi
 
 # Kill off any outstanding pid files.
 if [ -f /var/run/snarecore.pid ]; then
@@ -338,7 +367,11 @@ if [ $INSTALL_TYPE -eq 1 ] || [ $INSTALL_TYPE -eq 2 ] || [ $INSTALL_TYPE -eq 3 ]
    /usr/sbin/audit -T > /dev/null 2>&1
    sleep 2
 
-   /etc/init.d/audit stop
+   if [ $SMFAUDITD -ne 0 ]; then
+      /etc/init.d/audit stop
+   else
+      svcadm disable auditd
+   fi
    PID=`/usr/bin/ps -e -u 0|/usr/bin/fgrep auditd|/usr/bin/egrep -v fgrep|/usr/bin/awk '{print $1}'`
    if [ ! -z "$PID" ] ;  then
 	kill $PID
@@ -366,9 +399,17 @@ if [ $INSTALL_TYPE -eq 1 ] || [ $INSTALL_TYPE -eq 2 ] || [ $INSTALL_TYPE -eq 3 ]
    # Are we on a sparc or x86 arch?
    uname -a | grep i86pc > /dev/null
    if [ $? -eq 0 ]; then
-   	cp ./snarecore.x86 /usr/bin/snarecore
+	if [ $SMFAUDITD -ne 0 ]; then
+		cp ./snarecore.x86 /usr/bin/snarecore
+	else
+		cp ./snarecore.x86.smf /usr/bin/snarecore
+	fi
    else
-	cp ./snarecore.sparc /usr/bin/snarecore
+	if [ $SMFAUDITD -ne 0 ]; then
+		cp ./snarecore.sparc /usr/bin/snarecore
+	else
+		cp ./snarecore.sparc.smf /usr/bin/snarecore
+	fi
    fi
 
    RETVAL=$?
@@ -393,12 +434,38 @@ if [ $INSTALL_TYPE -eq 1 ] || [ $INSTALL_TYPE -eq 2 ] || [ $INSTALL_TYPE -eq 3 ]
      exit 1
    fi
 
-   cp ./audit_start.sh  /etc/init.d/audit
-   RETVAL=$?
-   if [ $RETVAL -gt 0 ]
-   then
-     echo "Unable to copy the startup script: /etc/init.d/audit. Terminating script"
-     exit 1
+   if [ $SMFAUDITD -ne 0 ]; then
+	   cp ./audit_start.sh  /etc/init.d/audit
+	   RETVAL=$?
+	   if [ $RETVAL -gt 0 ]
+	   then
+	     echo "Unable to copy the startup script: /etc/init.d/audit. Terminating script"
+	     exit 1
+	   fi
+   else
+	   cp ./snare.xml /var/svc/manifest/application/security/snare.xml
+	   RETVAL=$?
+	   if [ $RETVAL -gt 0 ]
+	   then
+	     echo "Unable to copy the startup script: /etc/init.d/audit. Terminating script"
+	     exit 1
+	   fi
+
+	   svccfg validate /var/svc/manifest/application/security/snare.xml
+	   RETVAL=$?
+	   if [ $RETVAL -gt 0 ]
+	   then
+	     echo "Unable to validate the SMF script: /var/svc/manifest/application/security/snare.xml. Terminating script"
+	     exit 1
+	   fi
+
+	   svccfg import /var/svc/manifest/application/security/snare.xml
+	   RETVAL=$?
+	   if [ $RETVAL -gt 0 ]
+	   then
+	     echo "Unable to import the SMF script: /var/svc/manifest/application/security/snare.xml. Terminating script"
+	     exit 1
+	   fi
    fi
 
    cp ./snare_start.sh  /etc/init.d/snare
@@ -463,14 +530,16 @@ if [ $INSTALL_TYPE -eq 1 ] || [ $INSTALL_TYPE -eq 2 ] || [ $INSTALL_TYPE -eq 3 ]
    #   echo "Unable to copy the SNARE GUI into /usr/bin. Continuing."
    #fi
 
-   ln /etc/init.d/snare /etc/rc0.d/K33snare
-   ln /etc/init.d/snare /etc/rc1.d/K33snare
-   ln /etc/init.d/snare /etc/rc2.d/S99zsnare
-   RETVAL=$?
-   if [ $RETVAL -gt 0 ]
-   then
-     echo "Unable to create etc/rc*.d files. Terminating script"
-     exit 1
+   if [ $SMFAUDITD -ne 0 ]; then
+	   ln /etc/init.d/snare /etc/rc0.d/K33snare
+	   ln /etc/init.d/snare /etc/rc1.d/K33snare
+	   ln /etc/init.d/snare /etc/rc2.d/S99zsnare
+	   RETVAL=$?
+	   if [ $RETVAL -gt 0 ]
+	   then
+	     echo "Unable to create etc/rc*.d files. Terminating script"
+	     exit 1
+	   fi
    fi
 
    echo
@@ -529,7 +598,7 @@ fi
 if [ $INSTALL_TYPE -eq 3 ]
 then
    echo
-   echo "Installing average configuration files..........."
+   echo "Installing advanced configuration files..........."
 
 
    cp ./snare.conf.advanced /etc/security/snare.conf
@@ -548,8 +617,20 @@ echo
 echo "Successfully installed the necessary files. Activating auditing..."
 echo 
 
-/etc/init.d/audit start
-/etc/init.d/snare start
+if [ $SMFAUDITD -ne 0 ]; then
+   /etc/init.d/audit start
+   /etc/init.d/snare start
+else
+  ./audit_start.sh start
+   # Kill off any outstanding pid files.
+   if [ -f /var/run/snarecore.pid ]; then
+	   rm -f /var/run/snarecore.pid >/dev/null 2>&1
+   fi
+   svcadm enable snare
+   sleep 2
+   #just to make sure that it has attached properly
+   #svcadm restart snare
+fi
 sleep 2
 
 PID=`/usr/bin/ps -e -u 0|/usr/bin/fgrep snarecor|/usr/bin/egrep -v fgrep|/usr/bin/awk '{print $1}'`
@@ -566,7 +647,12 @@ echo "Done."
 echo
 if [ $INSTALL_TYPE -ne 4 ]; then
         echo "Snare will also be activated after a reboot via the"
-        echo "init.d/snare startup script."
+	if [ $SMFAUDITD -ne 0 ]; then
+		echo "init.d/snare startup script."
+	else
+		echo "SMF startup script."
+	fi
+
 	echo
 	echo "Please connect to the local machine using your web browser"
 	echo "using the following URL: http://"`hostname`":6161/"
