@@ -42,20 +42,28 @@ root_check()
 
 restore_key_files()
 {
+if [ -f /usr/bin/svcs ]; then
+   svcs svc:/system/auditd:default > /dev/null 2>&1 
+   SMFAUDITD=$?
+else
+   SMFAUDITD=1
+fi
    echo "Restoring key files..........."
 
-   echo "Restoring oringinal /etc/init.d/audit..."
-   if [ -f /etc/security/audit.snare-backup ]
-   then
-      cp /etc/security/audit.snare-backup /etc/init.d/audit
-      RETVAL=$?
-      if [ $RETVAL -gt 0 ]
-      then
-        echo "Unable to restore /etc/init.d/audit to its original value."
-      fi
-   else
-	echo "Cannot find /etc/init.d/audit.snare-backup. Cannot restore."
-   fi 
+   if [ $SMFAUDITD -ne 0 ]; then
+	   echo "Restoring oringinal /etc/init.d/audit..."
+	   if [ -f /etc/security/audit.snare-backup ]
+	   then
+	      cp /etc/security/audit.snare-backup /etc/init.d/audit
+	      RETVAL=$?
+	      if [ $RETVAL -gt 0 ]
+	      then
+		echo "Unable to restore /etc/init.d/audit to its original value."
+	      fi
+	   else
+		echo "Cannot find /etc/init.d/audit.snare-backup. Cannot restore."
+	   fi 
+   fi
 
    echo "Restoring oringinal /etc/init.d/audit_control..."
    if [ -f /etc/security/audit_control.snare-backup ]
@@ -110,6 +118,13 @@ restore_key_files()
         echo "Done."
    fi
 
+   if [ -f /var/svc/manifest/application/security/snare.xml ]
+   then
+        echo "Removing snare SMF script..."
+        rm /var/svc/manifest/application/security/snare.xml 2>/dev/null
+        echo "Done."
+   fi
+
    echo "Removing snare backup files."
    rm -f /etc/security/*.snare-backup
    echo "Done."
@@ -117,17 +132,31 @@ restore_key_files()
    echo "I will leave the snare configuration file (/etc/security/snare.conf) - please remove it manually if you intend to permanently remove SNARE..."
 }
 
+if [ -f /usr/bin/svcs ]; then
+   svcs svc:/system/auditd:default > /dev/null 2>&1 
+   SMFAUDITD=$?
+else
+   SMFAUDITD=1
+fi
 /etc/init.d/snare stop
-/etc/init.d/audit stop
+if [ $SMFAUDITD -ne 0 ]; then
+	/etc/init.d/audit stop
+else
+	svcadm disable snare
+	svccfg delete snare
+fi
 
 root_check
 restore_key_files
 
 # Remove the snare-specific startup scripts
+/etc/init.d/snare stop
 rm /etc/init.d/snare 2>/dev/null
-rm /etc/rc0.d/K33snare 2>/dev/null
-rm /etc/rc1.d/K33snare 2>/dev/null
-rm /etc/rc2.d/S99zsnare 2>/dev/null
+if [ $SMFAUDITD -ne 0 ]; then
+	rm /etc/rc0.d/K33snare 2>/dev/null
+	rm /etc/rc1.d/K33snare 2>/dev/null
+	rm /etc/rc2.d/S99zsnare 2>/dev/null
+fi
 
 # remove documentation
 if [ -d /usr/share/doc/snare-for-solaris ]; then
@@ -139,3 +168,14 @@ fi
 
 rm -f /var/run/snarecore.pid 2>/dev/null
 rm -f /etc/security/snare_uninstall.sh
+
+if [ $SMFAUDITD -eq 0 ]; then
+	echo
+	echo "If you would like to use the SMF auditd service, please"
+	echo "disable BSM (/etc/security/bsmunconv), apply the"
+	echo "appropriate Kernel Updates and run the following"
+	echo "command:"
+	echo
+	echo "svcadm enable svc:/system/auditd:default"
+	echo
+fi
